@@ -1416,7 +1416,7 @@ globus_gsi_cred_read_cert_bio(
  */
 globus_result_t
 globus_gsi_cred_read_cert_buffer(
-    char *                              pem_buf,
+    const char *                        pem_buf,
     globus_gsi_cred_handle_t *          out_handle,
     X509 **                             out_cert,
     STACK_OF(X509) **                   out_cert_chain,
