@@ -224,7 +224,7 @@ globus_result_t globus_gsi_cred_read_cert_bio(
     BIO *                               bio);
 
 globus_result_t globus_gsi_cred_read_cert_buffer(
-    char *                              pem_buf,
+    const char *                        pem_buf,
     globus_gsi_cred_handle_t *          out_handle,
     X509 **                             out_cert,
     STACK_OF(X509) **                   out_cert_chain,
@@ -336,13 +336,15 @@ globus_result_t globus_gsi_cred_get_key_bits(
     globus_gsi_cred_handle_t            handle,
     int *                               key_bits);
 
+GLOBUS_DEPRECATED(
 globus_result_t globus_gsi_cred_handle_attrs_set_ca_cert_dir(
     globus_gsi_cred_handle_attrs_t      handle_attrs,
-    char *                              ca_cert_dir);
+    const char *                        ca_cert_dir));
 
+GLOBUS_DEPRECATED(
 globus_result_t globus_gsi_cred_handle_attrs_get_ca_cert_dir(
     globus_gsi_cred_handle_attrs_t      handle_attrs,
-    char **                             ca_cert_dir);
+    char **                             ca_cert_dir));
 
 globus_result_t globus_gsi_cred_handle_attrs_set_search_order(
     globus_gsi_cred_handle_attrs_t      handle_attrs,
